@@ -118,7 +118,7 @@ def run_zxpy(filename: str, module: ast.Module) -> None:
     patch_shell_commands(module)
     code = compile(module, filename, mode='exec')
     # Passing `__name__` in locals() to avoid overriding any globals
-    exec(code, None, {'__name__': '__main__'})
+    exec(code, {'__name__': '__main__'})
 
 
 def patch_shell_commands(module: Union[ast.Module, ast.Interactive]) -> None:
